#  fude.py
#
#  Created by Jun Kikuchi
#  Copyright (c) 2012 Jun Kikuchi. All rights reserved.
#
from xml.sax.saxutils import escape

def html(data):
    if isinstance(data, list):
        data = list(data)
        if data == []:
            return ''
        if isinstance(data[0], list):
            return ''.join([html(a) for a in data])

        xs_class = data.pop(0).split('.')
        xs_id = xs_class.pop(0).split('#')
        tag = xs_id.pop(0) or 'div'

        _attrs = {}
        if xs_id <> []:
            _attrs['id'] = xs_id.pop(0)
        if xs_class <> []:
            _attrs['class'] = ' '.join(xs_class)
        if data <> [] and isinstance(data[0], dict):
            _attrs.update(data.pop(0))

        attrs = ''
        if _attrs <> {}:
            attrs = ' ' + ' '.join([
                '%s="%s"' % (escape(k), escape(_attrs[k]))
                    for k in sorted(_attrs.keys())])

        if data <> []:
            container = [html(a) for a in data]
            return '<%s%s>%s</%s>' % (tag, attrs, ''.join(container), tag)
        else:
            return '<%s%s />' % (tag, attrs)
    else:
        return str(data)



# -*- coding: utf-8 -*-
from distutils.core import setup
setup(
    name = "fude",
    py_modules = ["fude"],
    version = "1.0.1",
    description = "Library for rendering HTML in Python",
    author = "Jun Kikuchi",
    author_email = "kikuchi@bonnou.com",
    url = "https://github.com/JunKikuchi/fude",
    download_url = "http://pypi.python.org/packages/source/f/fude/fude-1.0.0.tar.gz",
    keywords = ["html"],
    classifiers = [
        "Programming Language :: Python",
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing :: Markup :: HTML",
        ],
    long_description = """\
Fude (筆)
=========

Fude (筆) is a library for representing HTML in Python. It uses Lists to
represent elements, and Dicts to represent an element’s attributes.

Fude is inspired by Hiccup https://github.com/weavejester/hiccup

Syntax
------

Here is a basic example of Fude syntax:

::

    >>> fude.html('text')
    'text'

    >>> fude.html(['tag'])
    '<tag />'

    >>> fude.html(['div', 'bar'])
    '<div>bar</div>'

    >>> fude.html(['span', {'class': 'foo'}, 'bar'])
    '<span class="foo">bar</span>'

    >>> fude.html(['div', 'bar', ['span', 'baz'], ['span', 'bang']])
    '<div>bar<span>baz</span><span>bang</span></div>'

    >>> fude.html(['div', 'bar', [['span', 'baz'], ['span', 'bang']]])
    '<div>bar<span>baz</span><span>bang</span></div>'

The first element of the List is used as the element name. The second
attribute can optionally be a Dict, in which case it is used to supply
the element’s attributes. Every other element is considered part of the
tag’s body.

And provides a CSS-like shortcut for denoting ``id`` and ``class``
attributes:

::

    >>> fude.html(['div#foo.bar.baz', 'bang'])
    '<div class="bar baz" id="foo">bang</div>'

    >>> fude.html(['#foo.bar.baz', 'bang'])
    '<div class="bar baz" id="foo">bang</div>'

If the body of the element is a List, its contents will be expanded out
into the element body. This makes working with functions like ``map``
and ``List comprehensions``:

::

    >>> fude.html(['ul', [['li', x] for x in range(1, 4)]])
    '<ul><li>1</li><li>2</li><li>3</li></ul>'
"""
)
